@@ -1,11 +1,6 @@
 #!/bin/bash
 
-(perldoc -tU ./lib/Sys/Proctitle.pm
- perldoc -tU $0
-) >README
-
-exit 0
-
+perl -pe '/^=head1 DESCRIPTION/ and print <STDIN>' lib/Sys/Proctitle.pm >README.pod <<EOF
 =head1 INSTALLATION
 
  perl Makefile.PL
@@ -23,12 +18,11 @@ This module works only on linux.
 
 =item *
 
-Class::Member
-
-=item *
-
 perl 5.8.0
 
 =back
 
-=cut
\ No newline at end of file
+EOF
+
+perldoc -tU README.pod >README
+rm README.pod
